aboutsummaryrefslogtreecommitdiff
path: root/platform/ext/musca_b1.cmake
diff options
context:
space:
mode:
authorKevin Peng <kevin.peng@arm.com>2020-05-21 15:51:36 +0800
committerKevin Peng <kevin.peng@arm.com>2020-06-24 10:40:22 +0800
commit2131fdb1b7e450a87b86926d22fa8d6b962617ac (patch)
treeab0faefb6e7d95e3dafc6bf4153726da9b9d7174 /platform/ext/musca_b1.cmake
parent1fb8070ff51b88d4c79e438e6b0979d5239116b2 (diff)
downloadtrusted-firmware-m-2131fdb1b7e450a87b86926d22fa8d6b962617ac.tar.gz
Build: Replace CMSIS_5_DIR with deeper CMSIS_DIR
This patch replaces the CMake variable CMSIS_5_DIR with the deeper CMSIS_5_DIR/CMSIS. This is the preparation for the RTX references from CMSIS_5 repo to tf-m-tests repo. Because setting 'CMSIS_5_DIR' to 'tf-m-tests' could be confusing. With this change, the 'CMSIS_DIR' would be set to 'tf-m-tests/CMSIS' later. Change-Id: I3bf19d15592a24cb718b220d8efc49f42b40f56d Signed-off-by: Kevin Peng <kevin.peng@arm.com>
Diffstat (limited to 'platform/ext/musca_b1.cmake')
-rw-r--r--platform/ext/musca_b1.cmake12
1 files changed, 6 insertions, 6 deletions
diff --git a/platform/ext/musca_b1.cmake b/platform/ext/musca_b1.cmake
index 75ff37a201..2b825666bc 100644
--- a/platform/ext/musca_b1.cmake
+++ b/platform/ext/musca_b1.cmake
@@ -17,17 +17,17 @@ if (COMPILER STREQUAL "ARMCLANG")
set(S_SCATTER_FILE_NAME "${PLATFORM_DIR}/common/armclang/tfm_common_s.sct")
set(BL2_SCATTER_FILE_NAME "${PLATFORM_DIR}/target/musca_b1/Device/Source/armclang/musca_bl2.sct")
set(NS_SCATTER_FILE_NAME "${PLATFORM_DIR}/target/musca_b1/Device/Source/armclang/musca_ns.sct")
- if (DEFINED CMSIS_5_DIR)
- # Not all projects define CMSIS_5_DIR, only the ones that use it.
- set(RTX_LIB_PATH "${CMSIS_5_DIR}/CMSIS/RTOS2/RTX/Library/ARM/RTX_V8MMN.lib")
+ if (DEFINED CMSIS_DIR)
+ # Not all projects define CMSIS_DIR, only the ones that use it.
+ set(RTX_LIB_PATH "${CMSIS_DIR}/RTOS2/RTX/Library/ARM/RTX_V8MMN.lib")
endif()
elseif (COMPILER STREQUAL "GNUARM")
set(S_SCATTER_FILE_NAME "${PLATFORM_DIR}/common/gcc/tfm_common_s.ld")
set(BL2_SCATTER_FILE_NAME "${PLATFORM_DIR}/target/musca_b1/Device/Source/gcc/musca_bl2.ld")
set(NS_SCATTER_FILE_NAME "${PLATFORM_DIR}/target/musca_b1/Device/Source/gcc/musca_ns.ld")
- if (DEFINED CMSIS_5_DIR)
- # Not all projects define CMSIS_5_DIR, only the ones that use it.
- set(RTX_LIB_PATH "${CMSIS_5_DIR}/CMSIS/RTOS2/RTX/Library/GCC/libRTX_V8MMN.a")
+ if (DEFINED CMSIS_DIR)
+ # Not all projects define CMSIS_DIR, only the ones that use it.
+ set(RTX_LIB_PATH "${CMSIS_DIR}/RTOS2/RTX/Library/GCC/libRTX_V8MMN.a")
endif()
else()
message(FATAL_ERROR "No startup file is available for compiler '${CMAKE_C_COMPILER_ID}'.")